==========================
steamfitter Documentation
==========================

steamfitter is a set of tools for building and maintaining high-throughput data and modeling
pipelines at the `Institute for Health Metrics and Evaluation <https://www.healthdata.org/>`_.

.. toctree::
   :maxdepth: 2

   installation
   tutorials/index
   api_reference/index
   glossary
